"use strict";

exports.__esModule = true;
exports.truncateWords = exports.stringToSlug = exports.getUniqueNumber = exports.getHeight = exports.generateUUID = exports.generateSampleData = exports.fileListToArray = void 0;
var _uuid = require("uuid");
var sampleData = _interopRequireWildcard(require("../components/sampleFieldsData"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { "default": e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n["default"] = e, t && t.set(e, n), n; }
var generateUUID = exports.generateUUID = function generateUUID() {
  return (0, _uuid.v4)();
};
var getUniqueNumber = exports.getUniqueNumber = function getUniqueNumber() {
  return parseInt(Math.ceil(Math.random() * Date.now()).toPrecision(16).toString().replace(".", ""));
};
var stringToSlug = exports.stringToSlug = function stringToSlug(str) {
  str = str.replace(/^\s+|\s+$/g, ''); // trim
  str = str.toLowerCase();
  str = truncateWords(str, 4);

  // remove accents, swap ñ for n, etc
  var from = "àáäâèéëêìíïîòóöôùúüûñç·/_,:;";
  var to = "aaaaeeeeiiiioooouuuunc______";
  for (var i = 0, l = from.length; i < l; i++) {
    str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
  }
  str = str.replace(/[^a-z0-9 -]/g, '') // remove invalid chars
  .replace(/\s+/g, '_') // collapse whitespace and replace by -
  .replace(/-+/g, '_'); // collapse dashes

  return str;
};
var truncateWords = exports.truncateWords = function truncateWords(str, noWords) {
  return str.split(" ").splice(0, noWords).join(" ");
};
var generateSampleData = exports.generateSampleData = function generateSampleData(type, order) {
  var uuid = generateUUID();
  var machineName = type + '-' + Math.round(Date.now() / 1000);
  switch (type) {
    case 'text':
      return sampleData.textField(uuid, machineName, order);
    case 'select':
      return sampleData.selectField(uuid, machineName, order);
    case 'checkbox':
      return sampleData.checkboxField(uuid, machineName, order);
    case 'radio':
      return sampleData.radioField(uuid, machineName, order);
    case 'date':
      return sampleData.dateField(uuid, machineName, order);
    case 'file':
      return sampleData.fileField(uuid, machineName, order);
    case 'survey':
      return sampleData.surveyField(uuid, machineName, order);
    case 'quiz':
      return sampleData.quizField(uuid, machineName, order);
    case 'signature':
      return sampleData.signatureField(uuid, machineName, order);
    case 'content':
      return sampleData.contentField(uuid, machineName, order);
    case 'image':
      return sampleData.imageField(uuid, machineName, order);
    case 'video':
      return sampleData.videoField(uuid, machineName, order);
    case 'list':
      return sampleData.listField(uuid, machineName, order);
    case 'section':
      return sampleData.sectionField(uuid, machineName, order);
    default:
      return sampleData.textField(uuid, machineName, order);
  }
};
var fileListToArray = exports.fileListToArray = function fileListToArray(list) {
  var array = [];
  for (var i = 0; i < list.length; i++) {
    array.push(list.item(i));
  }
  return array;
};
var getHeight = exports.getHeight = function getHeight(toolbar, hasTabs) {
  if (toolbar === void 0) {
    toolbar = false;
  }
  if (hasTabs === void 0) {
    hasTabs = true;
  }
  var initial = 0;
  if (toolbar) {
    initial += 66;
  }
  if (hasTabs) {
    initial += 47;
  }
  return screen.height - initial - 180;
};